@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-utils.h,v 1.35 2005/12/12 17:27:56 pborelli Exp $
+ * $Id: gedit-utils.h,v 1.36 2005/12/29 15:13:39 pborelli Exp $
  */
 
 #ifndef __GEDIT_UTILS_H__
@@ -69,6 +69,12 @@ GtkWidget	*gedit_dialog_add_button		(GtkDialog   *dialog,
 							 const gchar *stock_id, 
 							 gint         response_id);
 
+gchar		*gedit_utils_escape_underscores		(const gchar *text,
+							 gssize       length);
+
+gchar		*gedit_utils_escape_slashes		(const gchar *text,
+							 gssize       length);
+
 gchar		*gedit_utils_str_middle_truncate	(const gchar *string, 
 							 guint        truncate_length);
 
